==> cost-interface-0.3.0-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/NormalPromotionPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.NormalPromotionRegistVo;

/**
 * 常规促销核报
 * NormalPromotionPayVo
 * 数据库表：normal_promotion_pay
 */
public class NormalPromotionPayVo implements Serializable {
	
	/**
	 * 登记单对象
	 */
	private NormalPromotionRegistVo normalPromotionRegistVo;

    /**
     * ID
     * 表字段 : normal_promotion_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : normal_promotion_pay.pay_no
     */
    private String payNo;

    /**
     * 登记单号
     * 表字段 : normal_promotion_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单行项目号
     * 表字段 : normal_promotion_pay.regist_item_no
     */
    private String registItemNo;

    /**
     * 登记单行项目ID
     * 表字段 : normal_promotion_pay.regist_item_id
     */
    private Integer registItemId;

    /**
     * 行项目号
     * 表字段 : normal_promotion_pay.item_no
     */
    private String itemNo;

    /**
     * 申请单号
     * 表字段 : normal_promotion_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型ID
     * 表字段 : normal_promotion_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : normal_promotion_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 产品ID
     * 表字段 : normal_promotion_pay.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : normal_promotion_pay.product_name
     */
    private String productName;

    /**
     * 结算价（分）
     * 表字段 : normal_promotion_pay.product_price
     */
    private BigDecimal productPrice;

    /**
     *  废弃
     * 表字段 : normal_promotion_pay.settlement_price
     */
    private BigDecimal settlementPrice;

    /**
     * 核报金额(分)
     * 表字段 : normal_promotion_pay.pay_amount
     */
    private BigDecimal payAmount;

    /**
     * 行项目余额
     * 表字段 : normal_promotion_pay.item_balance
     */
    private BigDecimal itemBalance;

    /**
     * 核报数量
     * 表字段 : normal_promotion_pay.num
     */
    private Integer num;

    /**
     * 督查意见
     * 表字段 : normal_promotion_pay.audit_notes
     */
    private String auditNotes;

    /**
     * 厂方承担比例
     * 表字段 : normal_promotion_pay.str1_str1
     */
    private String companyScale;

    /**
     * 备用字段2
     * 表字段 : normal_promotion_pay.str2_str2
     */
    private String str2Str2;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table normal_promotion_pay
     *
     * @mbggenerated Thu Jun 29 11:38:41 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:normal_promotion_pay.id
     *
     * @return normal_promotion_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:normal_promotion_pay.id
     *
     * @param id the value for normal_promotion_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 核报单号 字段:normal_promotion_pay.pay_no
     *
     * @return normal_promotion_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:normal_promotion_pay.pay_no
     *
     * @param payNo the value for normal_promotion_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 登记单号 字段:normal_promotion_pay.regist_no
     *
     * @return normal_promotion_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:normal_promotion_pay.regist_no
     *
     * @param registNo the value for normal_promotion_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:normal_promotion_pay.regist_item_no
     *
     * @return normal_promotion_pay.regist_item_no, 登记单行项目号
     */
    public String getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:normal_promotion_pay.regist_item_no
     *
     * @param registItemNo the value for normal_promotion_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 登记单行项目ID 字段:normal_promotion_pay.regist_item_id
     *
     * @return normal_promotion_pay.regist_item_id, 登记单行项目ID
     */
    public Integer getRegistItemId() {
        return registItemId;
    }

    /**
     * 设置 登记单行项目ID 字段:normal_promotion_pay.regist_item_id
     *
     * @param registItemId the value for normal_promotion_pay.regist_item_id, 登记单行项目ID
     */
    public void setRegistItemId(Integer registItemId) {
        this.registItemId = registItemId;
    }

    /**
     * 获取 行项目号 字段:normal_promotion_pay.item_no
     *
     * @return normal_promotion_pay.item_no, 行项目号
     */
    public String getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行项目号 字段:normal_promotion_pay.item_no
     *
     * @param itemNo the value for normal_promotion_pay.item_no, 行项目号
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 申请单号 字段:normal_promotion_pay.apply_no
     *
     * @return normal_promotion_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:normal_promotion_pay.apply_no
     *
     * @param applyNo the value for normal_promotion_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取  字段:normal_promotion_pay.cost_type_id
     *
     * @return normal_promotion_pay.cost_type_id, 
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置  字段:normal_promotion_pay.cost_type_id
     *
     * @param costTypeId the value for normal_promotion_pay.cost_type_id, 
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取  字段:normal_promotion_pay.cost_type_name
     *
     * @return normal_promotion_pay.cost_type_name, 
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置  字段:normal_promotion_pay.cost_type_name
     *
     * @param costTypeName the value for normal_promotion_pay.cost_type_name, 
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取  字段:normal_promotion_pay.product_id
     *
     * @return normal_promotion_pay.product_id, 
     */
    public String getProductId() {
        return productId;
    }

    /**
     * 设置  字段:normal_promotion_pay.product_id
     *
     * @param productId the value for normal_promotion_pay.product_id, 
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 获取  字段:normal_promotion_pay.product_name
     *
     * @return normal_promotion_pay.product_name, 
     */
    public String getProductName() {
        return productName;
    }

    /**
     * 设置  字段:normal_promotion_pay.product_name
     *
     * @param productName the value for normal_promotion_pay.product_name, 
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 获取 结算价（分） 字段:normal_promotion_pay.product_price
     *
     * @return normal_promotion_pay.product_price, 结算价（分）
     */
    public BigDecimal getProductPrice() {
    	if( this.productPrice != null) {
	          return (this.productPrice.divide(new BigDecimal(100),2,RoundingMode.HALF_UP));
	      }
	      return this.productPrice;
    }

    /**
     * 设置 结算价（分） 字段:normal_promotion_pay.product_price
     *
     * @param productPrice the value for normal_promotion_pay.product_price, 结算价（分）
     */
    public void setProductPrice(BigDecimal productPrice) {
        this.productPrice = productPrice;
    }

    /**
     * 获取  字段:normal_promotion_pay.settlement_price
     *
     * @return normal_promotion_pay.settlement_price, 
     */
    public BigDecimal getSettlementPrice() {
    	if( this.settlementPrice != null) {
	          return (this.settlementPrice.divide(new BigDecimal(100),2,RoundingMode.HALF_UP));
	      }
	      return this.settlementPrice;
    }

    /**
     * 设置  字段:normal_promotion_pay.settlement_price
     *
     * @param settlementPrice the value for normal_promotion_pay.settlement_price, 
     */
    public void setSettlementPrice(BigDecimal settlementPrice) {
        this.settlementPrice = settlementPrice;
    }

    /**
     * 获取 核报金额(分) 字段:normal_promotion_pay.pay_amount
     *
     * @return normal_promotion_pay.pay_amount, 核报金额(分)
     */
    public BigDecimal getPayAmount() {
    	if( this.payAmount != null) {
	          return (this.payAmount.divide(new BigDecimal(100),2,RoundingMode.HALF_UP));
	      }
	      return this.payAmount;
    }

    /**
     * 设置 核报金额(分) 字段:normal_promotion_pay.pay_amount
     *
     * @param payAmount the value for normal_promotion_pay.pay_amount, 核报金额(分)
     */
    public void setPayAmount(BigDecimal payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 获取 行项目余额 字段:normal_promotion_pay.item_balance
     *
     * @return normal_promotion_pay.item_balance, 行项目余额
     */
    public BigDecimal getItemBalance() {
    	if( this.itemBalance != null) {
	          return (this.itemBalance.divide(new BigDecimal(100),2,RoundingMode.HALF_UP));
	      }
	      return this.itemBalance;
    }

    /**
     * 设置 行项目余额 字段:normal_promotion_pay.item_balance
     *
     * @param itemBalance the value for normal_promotion_pay.item_balance, 行项目余额
     */
    public void setItemBalance(BigDecimal itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 核报数量 字段:normal_promotion_pay.num
     *
     * @return normal_promotion_pay.num, 核报数量
     */
    public Integer getNum() {
        return num;
    }

    /**
     * 设置 核报数量 字段:normal_promotion_pay.num
     *
     * @param num the value for normal_promotion_pay.num, 核报数量
     */
    public void setNum(Integer num) {
        this.num = num;
    }

    /**
     * 获取 督查意见 字段:normal_promotion_pay.audit_notes
     *
     * @return normal_promotion_pay.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:normal_promotion_pay.audit_notes
     *
     * @param auditNotes the value for normal_promotion_pay.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取  字段:normal_promotion_pay.str1_str1
     *
     * @return normal_promotion_pay.str1_str1, 
     */
    public String getCompanyScale() {
        return companyScale;
    }

    /**
     * 设置  字段:normal_promotion_pay.str1_str1
     *
     * @param companyScale the value for normal_promotion_pay.str1_str1, 
     */
    public void setCompanyScale(String companyScale) {
        this.companyScale = companyScale;
    }

    /**
     * 获取  字段:normal_promotion_pay.str2_str2
     *
     * @return normal_promotion_pay.str2_str2, 
     */
    public String getStr2Str2() {
        return str2Str2;
    }

    /**
     * 设置  字段:normal_promotion_pay.str2_str2
     *
     * @param str2Str2 the value for normal_promotion_pay.str2_str2, 
     */
    public void setStr2Str2(String str2Str2) {
        this.str2Str2 = str2Str2;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_id
     *
     * @return normal_promotion_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_id
     *
     * @param createId the value for normal_promotion_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_name
     *
     * @return normal_promotion_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_name
     *
     * @param createName the value for normal_promotion_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_date
     *
     * @return normal_promotion_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_date
     *
     * @param createDate the value for normal_promotion_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_id
     *
     * @return normal_promotion_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_id
     *
     * @param modifyId the value for normal_promotion_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_name
     *
     * @return normal_promotion_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_name
     *
     * @param modifyName the value for normal_promotion_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_date
     *
     * @return normal_promotion_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_date
     *
     * @param modifyDate the value for normal_promotion_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

	public NormalPromotionRegistVo getNormalPromotionRegistVo() {
		return normalPromotionRegistVo;
	}

	public void setNormalPromotionRegistVo(NormalPromotionRegistVo normalPromotionRegistVo) {
		this.normalPromotionRegistVo = normalPromotionRegistVo;
	}
    
}

==> cost-interface-0.3.3-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/NormalPromotionPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.NormalPromotionRegistVo;

/**
 * 常规促销品 核报
 * NormalPromotionPayVo
 * 数据库表：normal_promotion_pay
 */
public class NormalPromotionPayVo implements Serializable {
	private NormalPromotionRegistVo normalPromotionRegistVo;

    /**
     * ID
     * 表字段 : normal_promotion_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : normal_promotion_pay.pay_no
     */
    private String payNo;

    /**
     * 登记单号
     * 表字段 : normal_promotion_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单行项目号
     * 表字段 : normal_promotion_pay.regist_item_no
     */
    private String registItemNo;

    /**
     * 登记单行项目ID
     * 表字段 : normal_promotion_pay.regist_item_id
     */
    private Integer registItemId;

    /**
     * 行项目号
     * 表字段 : normal_promotion_pay.item_no
     */
    private String itemNo;

    /**
     * 申请单号
     * 表字段 : normal_promotion_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型ID
     * 表字段 : normal_promotion_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : normal_promotion_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 产品编号
     * 表字段 : normal_promotion_pay.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : normal_promotion_pay.product_name
     */
    private String productName;

    /**
     * 结算价（分）
     * 表字段 : normal_promotion_pay.product_price
     */
    private Long productPrice;

    /**
     * 
     * 表字段 : normal_promotion_pay.settlement_price
     */
    private Long settlementPrice;

    /**
     * 核报金额(分)
     * 表字段 : normal_promotion_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 行项目余额
     * 表字段 : normal_promotion_pay.item_balance
     */
    private Long itemBalance;

    /**
     * 核报数量
     * 表字段 : normal_promotion_pay.num
     */
    private Integer num;

    /**
     * 督查意见
     * 表字段 : normal_promotion_pay.audit_notes
     */
    private String auditNotes;

    /**
     * 厂方承担比例
     * 表字段 : normal_promotion_pay.company_scale
     */
    private Double companyScale;

    /**
     * 
     * 表字段 : normal_promotion_pay.str2_str2
     */
    private String str2Str2;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : normal_promotion_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : normal_promotion_pay.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table normal_promotion_pay
     *
     * @mbggenerated Thu Jun 29 11:38:41 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:normal_promotion_pay.id
     *
     * @return normal_promotion_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:normal_promotion_pay.id
     *
     * @param id the value for normal_promotion_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 核报单号 字段:normal_promotion_pay.pay_no
     *
     * @return normal_promotion_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:normal_promotion_pay.pay_no
     *
     * @param payNo the value for normal_promotion_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 登记单号 字段:normal_promotion_pay.regist_no
     *
     * @return normal_promotion_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:normal_promotion_pay.regist_no
     *
     * @param registNo the value for normal_promotion_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:normal_promotion_pay.regist_item_no
     *
     * @return normal_promotion_pay.regist_item_no, 登记单行项目号
     */
    public String getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:normal_promotion_pay.regist_item_no
     *
     * @param registItemNo the value for normal_promotion_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 登记单行项目ID 字段:normal_promotion_pay.regist_item_id
     *
     * @return normal_promotion_pay.regist_item_id, 登记单行项目ID
     */
    public Integer getRegistItemId() {
        return registItemId;
    }

    /**
     * 设置 登记单行项目ID 字段:normal_promotion_pay.regist_item_id
     *
     * @param registItemId the value for normal_promotion_pay.regist_item_id, 登记单行项目ID
     */
    public void setRegistItemId(Integer registItemId) {
        this.registItemId = registItemId;
    }

    /**
     * 获取 行项目号 字段:normal_promotion_pay.item_no
     *
     * @return normal_promotion_pay.item_no, 行项目号
     */
    public String getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行项目号 字段:normal_promotion_pay.item_no
     *
     * @param itemNo the value for normal_promotion_pay.item_no, 行项目号
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 申请单号 字段:normal_promotion_pay.apply_no
     *
     * @return normal_promotion_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:normal_promotion_pay.apply_no
     *
     * @param applyNo the value for normal_promotion_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取  字段:normal_promotion_pay.cost_type_id
     *
     * @return normal_promotion_pay.cost_type_id, 
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置  字段:normal_promotion_pay.cost_type_id
     *
     * @param costTypeId the value for normal_promotion_pay.cost_type_id, 
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取  字段:normal_promotion_pay.cost_type_name
     *
     * @return normal_promotion_pay.cost_type_name, 
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置  字段:normal_promotion_pay.cost_type_name
     *
     * @param costTypeName the value for normal_promotion_pay.cost_type_name, 
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取  字段:normal_promotion_pay.product_id
     *
     * @return normal_promotion_pay.product_id, 
     */
    public String getProductId() {
        return productId;
    }

    /**
     * 设置  字段:normal_promotion_pay.product_id
     *
     * @param productId the value for normal_promotion_pay.product_id, 
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 获取  字段:normal_promotion_pay.product_name
     *
     * @return normal_promotion_pay.product_name, 
     */
    public String getProductName() {
        return productName;
    }

    /**
     * 设置  字段:normal_promotion_pay.product_name
     *
     * @param productName the value for normal_promotion_pay.product_name, 
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 获取 结算价（分） 字段:normal_promotion_pay.product_price
     *
     * @return normal_promotion_pay.product_price, 结算价（分）
     */
    public Long getProductPrice() {
        return productPrice;
    }

    /**
     * 设置 结算价（分） 字段:normal_promotion_pay.product_price
     *
     * @param productPrice the value for normal_promotion_pay.product_price, 结算价（分）
     */
    public void setProductPrice(Long productPrice) {
        this.productPrice = productPrice;
    }

    /**
     * 获取  字段:normal_promotion_pay.settlement_price
     *
     * @return normal_promotion_pay.settlement_price, 
     */
    public Long getSettlementPrice() {
        return settlementPrice;
    }

    /**
     * 设置  字段:normal_promotion_pay.settlement_price
     *
     * @param settlementPrice the value for normal_promotion_pay.settlement_price, 
     */
    public void setSettlementPrice(Long settlementPrice) {
        this.settlementPrice = settlementPrice;
    }

    /**
     * 获取 核报金额(分) 字段:normal_promotion_pay.pay_amount
     *
     * @return normal_promotion_pay.pay_amount, 核报金额(分)
     */
    public Long getPayAmount() {
        return payAmount;
    }

    /**
     * 设置 核报金额(分) 字段:normal_promotion_pay.pay_amount
     *
     * @param payAmount the value for normal_promotion_pay.pay_amount, 核报金额(分)
     */
    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 获取 行项目余额 字段:normal_promotion_pay.item_balance
     *
     * @return normal_promotion_pay.item_balance, 行项目余额
     */
    public Long getItemBalance() {
        return itemBalance;
    }

    /**
     * 设置 行项目余额 字段:normal_promotion_pay.item_balance
     *
     * @param itemBalance the value for normal_promotion_pay.item_balance, 行项目余额
     */
    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 核报数量 字段:normal_promotion_pay.num
     *
     * @return normal_promotion_pay.num, 核报数量
     */
    public Integer getNum() {
        return num;
    }

    /**
     * 设置 核报数量 字段:normal_promotion_pay.num
     *
     * @param num the value for normal_promotion_pay.num, 核报数量
     */
    public void setNum(Integer num) {
        this.num = num;
    }

    /**
     * 获取 督查意见 字段:normal_promotion_pay.audit_notes
     *
     * @return normal_promotion_pay.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:normal_promotion_pay.audit_notes
     *
     * @param auditNotes the value for normal_promotion_pay.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取  字段:normal_promotion_pay.company_scale
     *
     * @return normal_promotion_pay.company_scale, 
     */
    public Double getCompanyScale() {
        return companyScale;
    }

    /**
     * 设置  字段:normal_promotion_pay.company_scale
     *
     * @param companyScale the value for normal_promotion_pay.company_scale, 
     */
    public void setCompanyScale(Double companyScale) {
        this.companyScale = companyScale;
    }

    /**
     * 获取  字段:normal_promotion_pay.str2_str2
     *
     * @return normal_promotion_pay.str2_str2, 
     */
    public String getStr2Str2() {
        return str2Str2;
    }

    /**
     * 设置  字段:normal_promotion_pay.str2_str2
     *
     * @param str2Str2 the value for normal_promotion_pay.str2_str2, 
     */
    public void setStr2Str2(String str2Str2) {
        this.str2Str2 = str2Str2;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_id
     *
     * @return normal_promotion_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_id
     *
     * @param createId the value for normal_promotion_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_name
     *
     * @return normal_promotion_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_name
     *
     * @param createName the value for normal_promotion_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:normal_promotion_pay.create_date
     *
     * @return normal_promotion_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:normal_promotion_pay.create_date
     *
     * @param createDate the value for normal_promotion_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_id
     *
     * @return normal_promotion_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_id
     *
     * @param modifyId the value for normal_promotion_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_name
     *
     * @return normal_promotion_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_name
     *
     * @param modifyName the value for normal_promotion_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:normal_promotion_pay.modify_date
     *
     * @return normal_promotion_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:normal_promotion_pay.modify_date
     *
     * @param modifyDate the value for normal_promotion_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

	public NormalPromotionRegistVo getNormalPromotionRegistVo() {
		return normalPromotionRegistVo;
	}

	public void setNormalPromotionRegistVo(NormalPromotionRegistVo normalPromotionRegistVo) {
		this.normalPromotionRegistVo = normalPromotionRegistVo;
	}
    
    
}
